@@ -1,7 +1,10 @@
+import logging
 import time
 import ujson
 import zmq
 
+logger = logging.getLogger(__name__)
+
 class Rumrunner(object):
     def __init__(self, metric_socket, app_name):
         self.metric_socket = metric_socket
@@ -26,14 +29,18 @@ class Rumrunner(object):
     def send(self, metric_name, value, metric_type):
         try:
             self.send_socket.send(ujson.dumps([self.app_name, metric_name, metric_type,  value]), zmq.NOBLOCK)
-        except zmq.error.Again:
-            pass
+        except zmq.error.Again, e:
+            logger.warn("Metric socket error - {0}".format(e))
 
 if __name__ == '__main__':
     m = Rumrunner('/var/tmp/metric_socket', 'test.app')
+    s = time.time()
     for x in range(1000):
         if x % 100 == 0:
             print x
         m.counter('test_counter', 1)
         m.gauge('test_gauge', x)
         m.percentile('test_percentile.', x)
+        time.sleep(0.000001)
+    e = time.time()
+    print "Took {0:.3f}s".format(e-s)
